:orphan:



.. _sphx_glr_auto_examples:

.. _general_examples:

Example Gallery
===============

Miscellaneous examples
----------------------

Miscellaneous and introductory examples for chop.


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Constrained neural network training.">

.. only:: html

 .. figure:: /auto_examples/images/thumb/sphx_glr_training_constrained_net_on_mnist_thumb.png
     :alt: Constrained neural network training.

     :ref:`sphx_glr_auto_examples_training_constrained_net_on_mnist.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/training_constrained_net_on_mnist

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Stochastic constrained optimization dynamics.">

.. only:: html

 .. figure:: /auto_examples/images/thumb/sphx_glr_plot_stochastic_dynamics_thumb.png
     :alt: Stochastic constrained optimization dynamics.

     :ref:`sphx_glr_auto_examples_plot_stochastic_dynamics.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_stochastic_dynamics

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Full-gradient constrained optimization dynamics.">

.. only:: html

 .. figure:: /auto_examples/images/thumb/sphx_glr_plot_optim_dynamics_thumb.png
     :alt: Full-gradient constrained optimization dynamics.

     :ref:`sphx_glr_auto_examples_plot_optim_dynamics.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/plot_optim_dynamics
.. raw:: html

    <div class="sphx-glr-clear"></div>



.. _sphx_glr_auto_examples_adversarial_robustness:

.. _adversarial_examples:


Adversarial Robustness
----------------------

Examples on adversarial robustness.


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Benchmark of attacks.">

.. only:: html

 .. figure:: /auto_examples/adversarial_robustness/images/thumb/sphx_glr_attack_benchmark_thumb.png
     :alt: Benchmark of attacks.

     :ref:`sphx_glr_auto_examples_adversarial_robustness_attack_benchmark.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/adversarial_robustness/attack_benchmark

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Example of robust training on CIFAR10.">

.. only:: html

 .. figure:: /auto_examples/adversarial_robustness/images/thumb/sphx_glr_plot_train_robust_cifar10_thumb.png
     :alt: Example of robust training on CIFAR10.

     :ref:`sphx_glr_auto_examples_adversarial_robustness_plot_train_robust_cifar10.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/adversarial_robustness/plot_train_robust_cifar10

.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="This example shows how to generate and plot adversarial examples for a batch of datapoints from...">

.. only:: html

 .. figure:: /auto_examples/adversarial_robustness/images/thumb/sphx_glr_plot_visualizing_adversarial_attacks_thumb.png
     :alt: Visualizing Adversarial Examples

     :ref:`sphx_glr_auto_examples_adversarial_robustness_plot_visualizing_adversarial_attacks.py`

.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/adversarial_robustness/plot_visualizing_adversarial_attacks
.. raw:: html

    <div class="sphx-glr-clear"></div>



.. only :: html

 .. container:: sphx-glr-footer
    :class: sphx-glr-footer-gallery


  .. container:: sphx-glr-download sphx-glr-download-python

    :download:`Download all examples in Python source code: auto_examples_python.zip </auto_examples/auto_examples_python.zip>`



  .. container:: sphx-glr-download sphx-glr-download-jupyter

    :download:`Download all examples in Jupyter notebooks: auto_examples_jupyter.zip </auto_examples/auto_examples_jupyter.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
